import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.club_model_status import ClubModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.club_model_additional_names import ClubModelAdditionalNames
    from ..models.club_model_club_address import ClubModelClubAddress
    from ..models.club_model_club_historical_name import ClubModelClubHistoricalName
    from ..models.club_model_colors import ClubModelColors
    from ..models.club_model_contact_details import ClubModelContactDetails
    from ..models.club_model_entity_additional_details import ClubModelEntityAdditionalDetails
    from ..models.club_model_organization import ClubModelOrganization
    from ..models.club_model_social_media import ClubModelSocialMedia
    from ..models.images_model import ImagesModel


T = TypeVar("T", bound="ClubModel")


@_attrs_define
class ClubModel:
    """
    Attributes:
        entity_group_id (Union[Unset, UUID]): The unique identifier of the club Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, ClubModelOrganization]): The organization that this club belongs to
        international_reference (Union[None, Unset, str]): The international reference for this club given by the sport
            governing body Example: CA3243-3.
        status (Union[Unset, ClubModelStatus]): Status
            >- `ACTIVE` Active
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
             Example: ACTIVE.
        name_full_local (Union[Unset, str]): The full name of the club in the [local](#section/Introduction/Character-
            Sets-and-Names) language Example: Los Angeles Armadillos.
        additional_names (Union[Unset, ClubModelAdditionalNames]):
        name_full_latin (Union[None, Unset, str]): The full name of the club in [latin](#section/Introduction/Character-
            Sets-and-Names) characters Example: Los Angeles Armadillos.
        code_local (Union[None, Unset, str]): The code of the club in the [local](#section/Introduction/Character-Sets-
            and-Names) language Example: TEST.
        code_latin (Union[None, Unset, str]): The code of the club in [latin](#section/Introduction/Character-Sets-and-
            Names) characters Example: TEST.
        address (Union['ClubModelClubAddress', None, Unset]): Street Address for the club
        social (Union['ClubModelSocialMedia', None, Unset]): Social Media contacts
        details (Union['ClubModelEntityAdditionalDetails', None, Unset]): Additional detail fields
        contacts (Union['ClubModelContactDetails', None, Unset]): Public contact fields
        colors (Union[Unset, ClubModelColors]):
        historical_names (Union[None, Unset, list['ClubModelClubHistoricalName']]): Array of club historical names
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
        default_venue_id (Union[None, UUID, Unset]): The unique identifier of the default venue Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        alternate_venue_ids (Union[Unset, list[UUID]]):
        images (Union[Unset, list['ImagesModel']]):
    """

    entity_group_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "ClubModelOrganization"] = UNSET
    international_reference: Union[None, Unset, str] = UNSET
    status: Union[Unset, ClubModelStatus] = UNSET
    name_full_local: Union[Unset, str] = UNSET
    additional_names: Union[Unset, "ClubModelAdditionalNames"] = UNSET
    name_full_latin: Union[None, Unset, str] = UNSET
    code_local: Union[None, Unset, str] = UNSET
    code_latin: Union[None, Unset, str] = UNSET
    address: Union["ClubModelClubAddress", None, Unset] = UNSET
    social: Union["ClubModelSocialMedia", None, Unset] = UNSET
    details: Union["ClubModelEntityAdditionalDetails", None, Unset] = UNSET
    contacts: Union["ClubModelContactDetails", None, Unset] = UNSET
    colors: Union[Unset, "ClubModelColors"] = UNSET
    historical_names: Union[None, Unset, list["ClubModelClubHistoricalName"]] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET
    default_venue_id: Union[None, UUID, Unset] = UNSET
    alternate_venue_ids: Union[Unset, list[UUID]] = UNSET
    images: Union[Unset, list["ImagesModel"]] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.club_model_club_address import ClubModelClubAddress
        from ..models.club_model_contact_details import ClubModelContactDetails
        from ..models.club_model_entity_additional_details import ClubModelEntityAdditionalDetails
        from ..models.club_model_social_media import ClubModelSocialMedia

        entity_group_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_group_id, Unset):
            entity_group_id = str(self.entity_group_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        international_reference: Union[None, Unset, str]
        if isinstance(self.international_reference, Unset):
            international_reference = UNSET
        else:
            international_reference = self.international_reference

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        name_full_local = self.name_full_local

        additional_names: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.additional_names, Unset):
            additional_names = self.additional_names.to_dict()

        name_full_latin: Union[None, Unset, str]
        if isinstance(self.name_full_latin, Unset):
            name_full_latin = UNSET
        else:
            name_full_latin = self.name_full_latin

        code_local: Union[None, Unset, str]
        if isinstance(self.code_local, Unset):
            code_local = UNSET
        else:
            code_local = self.code_local

        code_latin: Union[None, Unset, str]
        if isinstance(self.code_latin, Unset):
            code_latin = UNSET
        else:
            code_latin = self.code_latin

        address: Union[None, Unset, dict[str, Any]]
        if isinstance(self.address, Unset):
            address = UNSET
        elif isinstance(self.address, ClubModelClubAddress):
            address = self.address.to_dict()
        else:
            address = self.address

        social: Union[None, Unset, dict[str, Any]]
        if isinstance(self.social, Unset):
            social = UNSET
        elif isinstance(self.social, ClubModelSocialMedia):
            social = self.social.to_dict()
        else:
            social = self.social

        details: Union[None, Unset, dict[str, Any]]
        if isinstance(self.details, Unset):
            details = UNSET
        elif isinstance(self.details, ClubModelEntityAdditionalDetails):
            details = self.details.to_dict()
        else:
            details = self.details

        contacts: Union[None, Unset, dict[str, Any]]
        if isinstance(self.contacts, Unset):
            contacts = UNSET
        elif isinstance(self.contacts, ClubModelContactDetails):
            contacts = self.contacts.to_dict()
        else:
            contacts = self.contacts

        colors: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.colors, Unset):
            colors = self.colors.to_dict()

        historical_names: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.historical_names, Unset):
            historical_names = UNSET
        elif isinstance(self.historical_names, list):
            historical_names = []
            for historical_names_type_0_item_data in self.historical_names:
                historical_names_type_0_item = historical_names_type_0_item_data.to_dict()
                historical_names.append(historical_names_type_0_item)

        else:
            historical_names = self.historical_names

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        default_venue_id: Union[None, Unset, str]
        if isinstance(self.default_venue_id, Unset):
            default_venue_id = UNSET
        elif isinstance(self.default_venue_id, UUID):
            default_venue_id = str(self.default_venue_id)
        else:
            default_venue_id = self.default_venue_id

        alternate_venue_ids: Union[Unset, list[str]] = UNSET
        if not isinstance(self.alternate_venue_ids, Unset):
            alternate_venue_ids = []
            for alternate_venue_ids_item_data in self.alternate_venue_ids:
                alternate_venue_ids_item = str(alternate_venue_ids_item_data)
                alternate_venue_ids.append(alternate_venue_ids_item)

        images: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.images, Unset):
            images = []
            for images_item_data in self.images:
                images_item = images_item_data.to_dict()
                images.append(images_item)

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if international_reference is not UNSET:
            field_dict["internationalReference"] = international_reference
        if status is not UNSET:
            field_dict["status"] = status
        if name_full_local is not UNSET:
            field_dict["nameFullLocal"] = name_full_local
        if additional_names is not UNSET:
            field_dict["additionalNames"] = additional_names
        if name_full_latin is not UNSET:
            field_dict["nameFullLatin"] = name_full_latin
        if code_local is not UNSET:
            field_dict["codeLocal"] = code_local
        if code_latin is not UNSET:
            field_dict["codeLatin"] = code_latin
        if address is not UNSET:
            field_dict["address"] = address
        if social is not UNSET:
            field_dict["social"] = social
        if details is not UNSET:
            field_dict["details"] = details
        if contacts is not UNSET:
            field_dict["contacts"] = contacts
        if colors is not UNSET:
            field_dict["colors"] = colors
        if historical_names is not UNSET:
            field_dict["historicalNames"] = historical_names
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added
        if default_venue_id is not UNSET:
            field_dict["defaultVenueId"] = default_venue_id
        if alternate_venue_ids is not UNSET:
            field_dict["alternateVenueIds"] = alternate_venue_ids
        if images is not UNSET:
            field_dict["images"] = images

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.club_model_additional_names import ClubModelAdditionalNames
        from ..models.club_model_club_address import ClubModelClubAddress
        from ..models.club_model_club_historical_name import ClubModelClubHistoricalName
        from ..models.club_model_colors import ClubModelColors
        from ..models.club_model_contact_details import ClubModelContactDetails
        from ..models.club_model_entity_additional_details import ClubModelEntityAdditionalDetails
        from ..models.club_model_organization import ClubModelOrganization
        from ..models.club_model_social_media import ClubModelSocialMedia
        from ..models.images_model import ImagesModel

        d = dict(src_dict)
        _entity_group_id = d.pop("entityGroupId", UNSET)
        entity_group_id: Union[Unset, UUID]
        if isinstance(_entity_group_id, Unset):
            entity_group_id = UNSET
        else:
            entity_group_id = UUID(_entity_group_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, ClubModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = ClubModelOrganization.from_dict(_organization)

        def _parse_international_reference(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        international_reference = _parse_international_reference(d.pop("internationalReference", UNSET))

        _status = d.pop("status", UNSET)
        status: Union[Unset, ClubModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = ClubModelStatus(_status)

        name_full_local = d.pop("nameFullLocal", UNSET)

        _additional_names = d.pop("additionalNames", UNSET)
        additional_names: Union[Unset, ClubModelAdditionalNames]
        if isinstance(_additional_names, Unset):
            additional_names = UNSET
        else:
            additional_names = ClubModelAdditionalNames.from_dict(_additional_names)

        def _parse_name_full_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name_full_latin = _parse_name_full_latin(d.pop("nameFullLatin", UNSET))

        def _parse_code_local(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        code_local = _parse_code_local(d.pop("codeLocal", UNSET))

        def _parse_code_latin(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        code_latin = _parse_code_latin(d.pop("codeLatin", UNSET))

        def _parse_address(data: object) -> Union["ClubModelClubAddress", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                address_type_0 = ClubModelClubAddress.from_dict(data)

                return address_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ClubModelClubAddress", None, Unset], data)

        address = _parse_address(d.pop("address", UNSET))

        def _parse_social(data: object) -> Union["ClubModelSocialMedia", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                social_type_0 = ClubModelSocialMedia.from_dict(data)

                return social_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ClubModelSocialMedia", None, Unset], data)

        social = _parse_social(d.pop("social", UNSET))

        def _parse_details(data: object) -> Union["ClubModelEntityAdditionalDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                details_type_0 = ClubModelEntityAdditionalDetails.from_dict(data)

                return details_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ClubModelEntityAdditionalDetails", None, Unset], data)

        details = _parse_details(d.pop("details", UNSET))

        def _parse_contacts(data: object) -> Union["ClubModelContactDetails", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                contacts_type_0 = ClubModelContactDetails.from_dict(data)

                return contacts_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ClubModelContactDetails", None, Unset], data)

        contacts = _parse_contacts(d.pop("contacts", UNSET))

        _colors = d.pop("colors", UNSET)
        colors: Union[Unset, ClubModelColors]
        if isinstance(_colors, Unset):
            colors = UNSET
        else:
            colors = ClubModelColors.from_dict(_colors)

        def _parse_historical_names(data: object) -> Union[None, Unset, list["ClubModelClubHistoricalName"]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                historical_names_type_0 = []
                _historical_names_type_0 = data
                for historical_names_type_0_item_data in _historical_names_type_0:
                    historical_names_type_0_item = ClubModelClubHistoricalName.from_dict(
                        historical_names_type_0_item_data
                    )

                    historical_names_type_0.append(historical_names_type_0_item)

                return historical_names_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, list["ClubModelClubHistoricalName"]], data)

        historical_names = _parse_historical_names(d.pop("historicalNames", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        def _parse_default_venue_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                default_venue_id_type_0 = UUID(data)

                return default_venue_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        default_venue_id = _parse_default_venue_id(d.pop("defaultVenueId", UNSET))

        alternate_venue_ids = []
        _alternate_venue_ids = d.pop("alternateVenueIds", UNSET)
        for alternate_venue_ids_item_data in _alternate_venue_ids or []:
            alternate_venue_ids_item = UUID(alternate_venue_ids_item_data)

            alternate_venue_ids.append(alternate_venue_ids_item)

        images = []
        _images = d.pop("images", UNSET)
        for images_item_data in _images or []:
            images_item = ImagesModel.from_dict(images_item_data)

            images.append(images_item)

        club_model = cls(
            entity_group_id=entity_group_id,
            organization_id=organization_id,
            organization=organization,
            international_reference=international_reference,
            status=status,
            name_full_local=name_full_local,
            additional_names=additional_names,
            name_full_latin=name_full_latin,
            code_local=code_local,
            code_latin=code_latin,
            address=address,
            social=social,
            details=details,
            contacts=contacts,
            colors=colors,
            historical_names=historical_names,
            external_id=external_id,
            updated=updated,
            added=added,
            default_venue_id=default_venue_id,
            alternate_venue_ids=alternate_venue_ids,
            images=images,
        )

        return club_model



from enum import Enum


class StandingModelStandingConfigurationResourceType(str, Enum):
    STANDINGCONFIGURATIONS = "standingConfigurations"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class StandingConfigurationsModelStandingBuildingGrouping(str, Enum):
    NONE = "NONE"
    STAGE = "STAGE"
    STAGEPOOL = "STAGEPOOL"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.season_persons_model_status import SeasonPersonsModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.season_persons_model_entity_group import SeasonPersonsModelEntityGroup
    from ..models.season_persons_model_organization import SeasonPersonsModelOrganization
    from ..models.season_persons_model_person import SeasonPersonsModelPerson
    from ..models.season_persons_model_season import SeasonPersonsModelSeason


T = TypeVar("T", bound="SeasonPersonsModel")


@_attrs_define
class SeasonPersonsModel:
    """
    Attributes:
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, SeasonPersonsModelSeason]): The season linked to this record
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, SeasonPersonsModelOrganization]): The organization that this season persons belongs
            to
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, SeasonPersonsModelPerson]): The person information
        entity_group_id (Union[Unset, UUID]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, SeasonPersonsModelEntityGroup]): The club that this team belongs to
        status (Union[Unset, SeasonPersonsModelStatus]): Status
            >- `ACTIVE` Active
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
             Example: ACTIVE.
        seed (Union[Unset, int]): Initial seeding
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "SeasonPersonsModelSeason"] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "SeasonPersonsModelOrganization"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "SeasonPersonsModelPerson"] = UNSET
    entity_group_id: Union[Unset, UUID] = UNSET
    entity_group: Union[Unset, "SeasonPersonsModelEntityGroup"] = UNSET
    status: Union[Unset, SeasonPersonsModelStatus] = UNSET
    seed: Union[Unset, int] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        entity_group_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_group_id, Unset):
            entity_group_id = str(self.entity_group_id)

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        seed = self.seed

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if status is not UNSET:
            field_dict["status"] = status
        if seed is not UNSET:
            field_dict["seed"] = seed
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.season_persons_model_entity_group import SeasonPersonsModelEntityGroup
        from ..models.season_persons_model_organization import SeasonPersonsModelOrganization
        from ..models.season_persons_model_person import SeasonPersonsModelPerson
        from ..models.season_persons_model_season import SeasonPersonsModelSeason

        d = dict(src_dict)
        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, SeasonPersonsModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = SeasonPersonsModelSeason.from_dict(_season)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, SeasonPersonsModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = SeasonPersonsModelOrganization.from_dict(_organization)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, SeasonPersonsModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = SeasonPersonsModelPerson.from_dict(_person)

        _entity_group_id = d.pop("entityGroupId", UNSET)
        entity_group_id: Union[Unset, UUID]
        if isinstance(_entity_group_id, Unset):
            entity_group_id = UNSET
        else:
            entity_group_id = UUID(_entity_group_id)

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, SeasonPersonsModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = SeasonPersonsModelEntityGroup.from_dict(_entity_group)

        _status = d.pop("status", UNSET)
        status: Union[Unset, SeasonPersonsModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = SeasonPersonsModelStatus(_status)

        seed = d.pop("seed", UNSET)

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        season_persons_model = cls(
            season_id=season_id,
            season=season,
            organization_id=organization_id,
            organization=organization,
            person_id=person_id,
            person=person,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            status=status,
            seed=seed,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return season_persons_model



from enum import Enum


class VideoStreamInputsOrgListFeedType(str, Enum):
    ADDITIONAL_ANGLE = "ADDITIONAL_ANGLE"
    LOW_LATENCY = "LOW_LATENCY"
    PRIMARY = "PRIMARY"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="UniformItemsModelColors")


@_attrs_define
class UniformItemsModelColors:
    """
    Attributes:
        lettering (Union[None, Unset, str]): Primary color of the Uniform Item Lettering.  Colors are a hexadecimal
            string `RRGGBB` with `RR`(red), `GG`(green) and `BB`(blue) representing the components of the colour.  Example:
            FFF111.
        primary (Union[None, Unset, str]): Primary color of the uniform_items.  Colors are a hexadecimal string `RRGGBB`
            with `RR`(red), `GG`(green) and `BB`(blue) representing the components of the colour.  Example: FFF111.
        secondary (Union[None, Unset, str]): Secondary color of the uniform_items.  Colors are a hexadecimal string
            `RRGGBB` with `RR`(red), `GG`(green) and `BB`(blue) representing the components of the colour.  Example: FFF111.
        tertiary (Union[None, Unset, str]): Tertiary color of the uniform_items.  Colors are a hexadecimal string
            `RRGGBB` with `RR`(red), `GG`(green) and `BB`(blue) representing the components of the colour.  Example: FFF111.
    """

    lettering: Union[None, Unset, str] = UNSET
    primary: Union[None, Unset, str] = UNSET
    secondary: Union[None, Unset, str] = UNSET
    tertiary: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        lettering: Union[None, Unset, str]
        if isinstance(self.lettering, Unset):
            lettering = UNSET
        else:
            lettering = self.lettering

        primary: Union[None, Unset, str]
        if isinstance(self.primary, Unset):
            primary = UNSET
        else:
            primary = self.primary

        secondary: Union[None, Unset, str]
        if isinstance(self.secondary, Unset):
            secondary = UNSET
        else:
            secondary = self.secondary

        tertiary: Union[None, Unset, str]
        if isinstance(self.tertiary, Unset):
            tertiary = UNSET
        else:
            tertiary = self.tertiary

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if lettering is not UNSET:
            field_dict["lettering"] = lettering
        if primary is not UNSET:
            field_dict["primary"] = primary
        if secondary is not UNSET:
            field_dict["secondary"] = secondary
        if tertiary is not UNSET:
            field_dict["tertiary"] = tertiary

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_lettering(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        lettering = _parse_lettering(d.pop("lettering", UNSET))

        def _parse_primary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        primary = _parse_primary(d.pop("primary", UNSET))

        def _parse_secondary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        secondary = _parse_secondary(d.pop("secondary", UNSET))

        def _parse_tertiary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        tertiary = _parse_tertiary(d.pop("tertiary", UNSET))

        uniform_items_model_colors = cls(
            lettering=lettering,
            primary=primary,
            secondary=secondary,
            tertiary=tertiary,
        )

        uniform_items_model_colors.additional_properties = d
        return uniform_items_model_colors

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import httpx

from ...client import AuthenticatedClient, Client
from ...models.video_stream_outputs_orggroup_list_content import VideoStreamOutputsOrggroupListContent
from ...models.video_stream_outputs_orggroup_list_feed_type import VideoStreamOutputsOrggroupListFeedType
from ...models.video_stream_outputs_orggroup_list_response_default import VideoStreamOutputsOrggroupListResponseDefault
from ...models.video_stream_outputs_orggroup_list_video_stream_outputs_response import (
    VideoStreamOutputsOrggroupListVideoStreamOutputsResponse,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    organization_group_code: str,
    *,
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    content: Union[Unset, VideoStreamOutputsOrggroupListContent] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamOutputsOrggroupListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    master_venue_id: Union[Unset, UUID] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    json_added: Union[Unset, str] = UNSET
    if not isinstance(added, Unset):
        json_added = added.isoformat()
    params["added"] = json_added

    json_competition_id: Union[Unset, str] = UNSET
    if not isinstance(competition_id, Unset):
        json_competition_id = str(competition_id)
    params["competitionId"] = json_competition_id

    json_content: Union[Unset, str] = UNSET
    if not isinstance(content, Unset):
        json_content = content.value

    params["content"] = json_content

    params["external"] = external

    json_feed_type: Union[Unset, str] = UNSET
    if not isinstance(feed_type, Unset):
        json_feed_type = feed_type.value

    params["feedType"] = json_feed_type

    params["fields"] = fields

    json_from_time_utc: Union[Unset, str] = UNSET
    if not isinstance(from_time_utc, Unset):
        json_from_time_utc = from_time_utc.isoformat()
    params["fromTimeUTC"] = json_from_time_utc

    params["hideNull"] = hide_null

    params["include"] = include

    params["limit"] = limit

    params["locale"] = locale

    json_master_venue_id: Union[Unset, str] = UNSET
    if not isinstance(master_venue_id, Unset):
        json_master_venue_id = str(master_venue_id)
    params["masterVenueId"] = json_master_venue_id

    params["offset"] = offset

    params["provider"] = provider

    json_season_id: Union[Unset, str] = UNSET
    if not isinstance(season_id, Unset):
        json_season_id = str(season_id)
    params["seasonId"] = json_season_id

    params["sourceNumber"] = source_number

    json_to_time_utc: Union[Unset, str] = UNSET
    if not isinstance(to_time_utc, Unset):
        json_to_time_utc = to_time_utc.isoformat()
    params["toTimeUTC"] = json_to_time_utc

    json_updated: Union[Unset, str] = UNSET
    if not isinstance(updated, Unset):
        json_updated = updated.isoformat()
    params["updated"] = json_updated

    json_venue_id: Union[Unset, str] = UNSET
    if not isinstance(venue_id, Unset):
        json_venue_id = str(venue_id)
    params["venueId"] = json_venue_id

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/handball/orgGroup/{organization_group_code}/video/streams/available",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]:
    if response.status_code == 200:
        response_200 = VideoStreamOutputsOrggroupListVideoStreamOutputsResponse.from_dict(response.json())

        return response_200

    response_default = VideoStreamOutputsOrggroupListResponseDefault.from_dict(response.json())

    return response_default


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[
    Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    organization_group_code: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    content: Union[Unset, VideoStreamOutputsOrggroupListContent] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamOutputsOrggroupListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    master_venue_id: Union[Unset, UUID] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
) -> Response[
    Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
]:
    """List available video streams for the ~organization group~

     Display the list of video streams for the organization group. Streams for completed matches and
    those older than 12 hours, will not be displayed.

    Args:
        organization_group_code (str):  Example: aubb.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        content (Union[Unset, VideoStreamOutputsOrggroupListContent]):  Example: CLEAN.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamOutputsOrggroupListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        master_venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]]
    """

    kwargs = _get_kwargs(
        organization_group_code=organization_group_code,
        added=added,
        competition_id=competition_id,
        content=content,
        external=external,
        feed_type=feed_type,
        fields=fields,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        locale=locale,
        master_venue_id=master_venue_id,
        offset=offset,
        provider=provider,
        season_id=season_id,
        source_number=source_number,
        to_time_utc=to_time_utc,
        updated=updated,
        venue_id=venue_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    organization_group_code: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    content: Union[Unset, VideoStreamOutputsOrggroupListContent] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamOutputsOrggroupListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    master_venue_id: Union[Unset, UUID] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
) -> Optional[
    Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
]:
    """List available video streams for the ~organization group~

     Display the list of video streams for the organization group. Streams for completed matches and
    those older than 12 hours, will not be displayed.

    Args:
        organization_group_code (str):  Example: aubb.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        content (Union[Unset, VideoStreamOutputsOrggroupListContent]):  Example: CLEAN.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamOutputsOrggroupListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        master_venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
    """

    return sync_detailed(
        organization_group_code=organization_group_code,
        client=client,
        added=added,
        competition_id=competition_id,
        content=content,
        external=external,
        feed_type=feed_type,
        fields=fields,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        locale=locale,
        master_venue_id=master_venue_id,
        offset=offset,
        provider=provider,
        season_id=season_id,
        source_number=source_number,
        to_time_utc=to_time_utc,
        updated=updated,
        venue_id=venue_id,
    ).parsed


async def asyncio_detailed(
    organization_group_code: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    content: Union[Unset, VideoStreamOutputsOrggroupListContent] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamOutputsOrggroupListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    master_venue_id: Union[Unset, UUID] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
) -> Response[
    Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
]:
    """List available video streams for the ~organization group~

     Display the list of video streams for the organization group. Streams for completed matches and
    those older than 12 hours, will not be displayed.

    Args:
        organization_group_code (str):  Example: aubb.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        content (Union[Unset, VideoStreamOutputsOrggroupListContent]):  Example: CLEAN.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamOutputsOrggroupListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        master_venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]]
    """

    kwargs = _get_kwargs(
        organization_group_code=organization_group_code,
        added=added,
        competition_id=competition_id,
        content=content,
        external=external,
        feed_type=feed_type,
        fields=fields,
        from_time_utc=from_time_utc,
        hide_null=hide_null,
        include=include,
        limit=limit,
        locale=locale,
        master_venue_id=master_venue_id,
        offset=offset,
        provider=provider,
        season_id=season_id,
        source_number=source_number,
        to_time_utc=to_time_utc,
        updated=updated,
        venue_id=venue_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    organization_group_code: str,
    *,
    client: Union[AuthenticatedClient, Client],
    added: Union[Unset, datetime.datetime] = UNSET,
    competition_id: Union[Unset, UUID] = UNSET,
    content: Union[Unset, VideoStreamOutputsOrggroupListContent] = UNSET,
    external: Union[Unset, str] = UNSET,
    feed_type: Union[Unset, VideoStreamOutputsOrggroupListFeedType] = UNSET,
    fields: Union[Unset, str] = UNSET,
    from_time_utc: Union[Unset, datetime.datetime] = UNSET,
    hide_null: Union[Unset, bool] = UNSET,
    include: Union[Unset, str] = UNSET,
    limit: Union[Unset, int] = 10,
    locale: Union[Unset, str] = UNSET,
    master_venue_id: Union[Unset, UUID] = UNSET,
    offset: Union[Unset, int] = UNSET,
    provider: Union[Unset, str] = UNSET,
    season_id: Union[Unset, UUID] = UNSET,
    source_number: Union[Unset, int] = UNSET,
    to_time_utc: Union[Unset, datetime.datetime] = UNSET,
    updated: Union[Unset, datetime.datetime] = UNSET,
    venue_id: Union[Unset, UUID] = UNSET,
) -> Optional[
    Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
]:
    """List available video streams for the ~organization group~

     Display the list of video streams for the organization group. Streams for completed matches and
    those older than 12 hours, will not be displayed.

    Args:
        organization_group_code (str):  Example: aubb.
        added (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:10:48.
        competition_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        content (Union[Unset, VideoStreamOutputsOrggroupListContent]):  Example: CLEAN.
        external (Union[Unset, str]):  Example: entityId,personId.
        feed_type (Union[Unset, VideoStreamOutputsOrggroupListFeedType]):  Example: PRIMARY.
        fields (Union[Unset, str]):  Example: dob,firstName,organization(id),organizations[name],
            teams[name,details/metrics/*,tags(id)].
        from_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        hide_null (Union[Unset, bool]):  Example: True.
        include (Union[Unset, str]):  Example: organizations,fixtures,entities.
        limit (Union[Unset, int]):  Default: 10. Example: 10.
        locale (Union[Unset, str]):  Example: fr_FR.
        master_venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        offset (Union[Unset, int]):  Example: 10.
        provider (Union[Unset, str]):  Example: Test Provider.
        season_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        source_number (Union[Unset, int]):  Example: 1.
        to_time_utc (Union[Unset, datetime.datetime]):  Example: 2018-08-16T18:00:00.
        updated (Union[Unset, datetime.datetime]):  Example: 2018-08-16T02:11:48.
        venue_id (Union[Unset, UUID]):  Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[VideoStreamOutputsOrggroupListResponseDefault, VideoStreamOutputsOrggroupListVideoStreamOutputsResponse]
    """

    return (
        await asyncio_detailed(
            organization_group_code=organization_group_code,
            client=client,
            added=added,
            competition_id=competition_id,
            content=content,
            external=external,
            feed_type=feed_type,
            fields=fields,
            from_time_utc=from_time_utc,
            hide_null=hide_null,
            include=include,
            limit=limit,
            locale=locale,
            master_venue_id=master_venue_id,
            offset=offset,
            provider=provider,
            season_id=season_id,
            source_number=source_number,
            to_time_utc=to_time_utc,
            updated=updated,
            venue_id=venue_id,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.conduct_model_conduct_type_item import ConductModelConductTypeItem
from ..models.conduct_model_fine_status_type_1 import ConductModelFineStatusType1
from ..models.conduct_model_fine_status_type_2_type_1 import ConductModelFineStatusType2Type1
from ..models.conduct_model_fine_status_type_3_type_1 import ConductModelFineStatusType3Type1
from ..models.conduct_model_hearing_status_type_1 import ConductModelHearingStatusType1
from ..models.conduct_model_hearing_status_type_2_type_1 import ConductModelHearingStatusType2Type1
from ..models.conduct_model_hearing_status_type_3_type_1 import ConductModelHearingStatusType3Type1
from ..models.conduct_model_period_id import ConductModelPeriodId
from ..models.conduct_model_role_type_1 import ConductModelRoleType1
from ..models.conduct_model_role_type_2_type_1 import ConductModelRoleType2Type1
from ..models.conduct_model_role_type_3_type_1 import ConductModelRoleType3Type1
from ..models.conduct_model_status_type_1 import ConductModelStatusType1
from ..models.conduct_model_status_type_2_type_1 import ConductModelStatusType2Type1
from ..models.conduct_model_status_type_3_type_1 import ConductModelStatusType3Type1
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.conduct_model_competition import ConductModelCompetition
    from ..models.conduct_model_conduct_penalty_result import ConductModelConductPenaltyResult
    from ..models.conduct_model_entity import ConductModelEntity
    from ..models.conduct_model_entity_group import ConductModelEntityGroup
    from ..models.conduct_model_fixture import ConductModelFixture
    from ..models.conduct_model_organization import ConductModelOrganization
    from ..models.conduct_model_person import ConductModelPerson
    from ..models.conduct_model_season import ConductModelSeason
    from ..models.conduct_model_venue import ConductModelVenue


T = TypeVar("T", bound="ConductModel")


@_attrs_define
class ConductModel:
    """
    Attributes:
        conduct_id (Union[Unset, UUID]): The unique identifier of the conduct Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, ConductModelOrganization]): The organization that this conduct belongs to
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, ConductModelPerson]): The person information
        entity_group_id (Union[Unset, UUID]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, ConductModelEntityGroup]): The club that this team belongs to
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, ConductModelEntity]): The team information
        venue_id (Union[Unset, UUID]): The unique identifier of the venue Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        venue (Union[Unset, ConductModelVenue]): The venue that this match belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, ConductModelFixture]): The match
        season_id (Union[Unset, UUID]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, ConductModelSeason]): The season linked to this record
        competition_id (Union[Unset, UUID]): The unique identifier of the competition Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        competition (Union[Unset, ConductModelCompetition]): The competition that this season belongs to
        bib (Union[None, Unset, str]): The number displayed on the jersey Example: 34.
        location_other (Union[None, Unset, str]): The location where the incident occurred Example: location.
        event_id (Union[Unset, UUID]): The ~event~ that this conduct is linked to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        period_id (Union[Unset, ConductModelPeriodId]): The identifier for the period
            >- `1` Period 1
            >- `2` Period 2
            >- `10` Extra time 1 period 1
            >- `11` Extra time 1 period 2
            >- `12` Extra time 2 period 1
            >- `13` Extra time 2 period 2
            >- `14` Shoot Out
        section (Union[Unset, str]): The section of the period (sub-period)
        fixture_clock (Union[None, Unset, str]): Match clock when the incident occurred Example: PT9M53S.
        role (Union[ConductModelRoleType1, ConductModelRoleType2Type1, ConductModelRoleType3Type1, None, Unset]): The
            role of person
            >- None None
            >- `ASSISTANT_REFEREE_1` Assistant Referee 1
            >- `ASSISTANT_REFEREE_2` Assistant Referee 2
            >- `CLUB_IT_OFFICER` Club IT Officer
            >- `CLUB_OFFICIAL` Club Official
            >- `CLUB_OFFICIAL_ASSISTANT` Substitute for contact person of club
            >- `COACH` Coach
            >- `COACH_ASSISTANT` Coach Assistant
            >- `COACH_HEAD` Coach Head
            >- `DELEGATE` Delegate
            >- `DIRECTOR` Director
            >- `LIAISON_OFFICER` Liaison Officer
            >- `MATCH_LIAISON` Match Liaison
            >- `MATCH_SUPERVISOR` Match Supervisor
            >- `MEDIA_OFFICER` Media Officer
            >- `OFFICE_STAFF` Office Staff
            >- `OFFICIAL_A` Official A
            >- `OFFICIAL_B` Official B
            >- `OFFICIAL_C` Official C
            >- `OFFICIAL_D` Official D
            >- `OFFICIAL_E` Official E
            >- `PLAYER_CONTRACT_MANAGER` Player Contract Manager
            >- `REFEREE` Referee
            >- `REFEREE_LIAISON` Referee Liaison
            >- `REFEREE_OBSERVER` Referee Observer
            >- `REFEREE_OBSERVER_LIAISON` Referee Observer Liaison
            >- `SCOREKEEPER` Scorekeeper
            >- `SCOUT_1` Scout 1
            >- `SCOUT_2` Scout 2
            >- `SCOUT_3` Scout 3
            >- `SCOUT_SUPERVISOR` Scout Supervisor
            >- `SECRETARY` Secretary
            >- `SPORT_DIRECTOR` Sporting Director
            >- `TEAM_COORDINATOR` Team Coordinator
            >- `TIMEKEEPER` Timekeeper
            >- `TRAINER` Trainer
            >- `YOUTH_COORDINATOR` Youth Coordinator
             Example: COACH.
        date_offence_local (Union[None, Unset, datetime.datetime]): Date & Time of the Offence in the local timezone
            Example: 1978-08-24T12:12:12.
        conduct_type (Union[Unset, list[ConductModelConductTypeItem]]):
        conduct_notes (Union[None, Unset, str]): Notes of the Conduct incident
        date_hearing_local (Union[None, Unset, datetime.date]): Date hearing Example: 1978-08-24.
        hearing_notes (Union[None, Unset, str]): Notes from the conduct hearing
        hearing_status (Union[ConductModelHearingStatusType1, ConductModelHearingStatusType2Type1,
            ConductModelHearingStatusType3Type1, None, Unset]): Conduct hearing status
            >- None None
            >- `FINALIZED` Finalized
            >- `PENDING` Pending
             Example: PENDING.
        life_sentence (Union[Unset, bool]): Was the result of the conduct hearing a life sentence? Example: True.
        penalty_results (Union[Unset, list[Union['ConductModelConductPenaltyResult', None]]]):
        fine_amount (Union[Unset, float]): Conduct fine amount
        fine_currency (Union[None, Unset, str]): Fine currency Example: USD.
        fine_status (Union[ConductModelFineStatusType1, ConductModelFineStatusType2Type1,
            ConductModelFineStatusType3Type1, None, Unset]): Conduct fine due status
            >- None None
            >- `CANCELLED` Cancelled
            >- `ISSUED` Issued
            >- `OTHER` Other
            >- `PAID` Paid
            >- `UNPAID` Unpaid
             Example: PAID.
        date_suspended_to (Union[None, Unset, datetime.date]): Date the suspension ended Example: 1978-08-24.
        date_suspended_from (Union[None, Unset, datetime.date]): Date the suspension started Example: 1978-08-24.
        date_fine_paid_local (Union[None, Unset, datetime.date]): Date the fine was paid Example: 1978-08-24.
        status (Union[ConductModelStatusType1, ConductModelStatusType2Type1, ConductModelStatusType3Type1, None,
            Unset]): Conduct status
            >- None None
            >- `ACTIVE` Active
            >- `CLOSED` Closed
            >- `COMPLETE` Complete
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
             Example: ACTIVE.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    conduct_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "ConductModelOrganization"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "ConductModelPerson"] = UNSET
    entity_group_id: Union[Unset, UUID] = UNSET
    entity_group: Union[Unset, "ConductModelEntityGroup"] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "ConductModelEntity"] = UNSET
    venue_id: Union[Unset, UUID] = UNSET
    venue: Union[Unset, "ConductModelVenue"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "ConductModelFixture"] = UNSET
    season_id: Union[Unset, UUID] = UNSET
    season: Union[Unset, "ConductModelSeason"] = UNSET
    competition_id: Union[Unset, UUID] = UNSET
    competition: Union[Unset, "ConductModelCompetition"] = UNSET
    bib: Union[None, Unset, str] = UNSET
    location_other: Union[None, Unset, str] = UNSET
    event_id: Union[Unset, UUID] = UNSET
    period_id: Union[Unset, ConductModelPeriodId] = UNSET
    section: Union[Unset, str] = UNSET
    fixture_clock: Union[None, Unset, str] = UNSET
    role: Union[ConductModelRoleType1, ConductModelRoleType2Type1, ConductModelRoleType3Type1, None, Unset] = UNSET
    date_offence_local: Union[None, Unset, datetime.datetime] = UNSET
    conduct_type: Union[Unset, list[ConductModelConductTypeItem]] = UNSET
    conduct_notes: Union[None, Unset, str] = UNSET
    date_hearing_local: Union[None, Unset, datetime.date] = UNSET
    hearing_notes: Union[None, Unset, str] = UNSET
    hearing_status: Union[
        ConductModelHearingStatusType1,
        ConductModelHearingStatusType2Type1,
        ConductModelHearingStatusType3Type1,
        None,
        Unset,
    ] = UNSET
    life_sentence: Union[Unset, bool] = UNSET
    penalty_results: Union[Unset, list[Union["ConductModelConductPenaltyResult", None]]] = UNSET
    fine_amount: Union[Unset, float] = UNSET
    fine_currency: Union[None, Unset, str] = UNSET
    fine_status: Union[
        ConductModelFineStatusType1, ConductModelFineStatusType2Type1, ConductModelFineStatusType3Type1, None, Unset
    ] = UNSET
    date_suspended_to: Union[None, Unset, datetime.date] = UNSET
    date_suspended_from: Union[None, Unset, datetime.date] = UNSET
    date_fine_paid_local: Union[None, Unset, datetime.date] = UNSET
    status: Union[ConductModelStatusType1, ConductModelStatusType2Type1, ConductModelStatusType3Type1, None, Unset] = (
        UNSET
    )
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.conduct_model_conduct_penalty_result import ConductModelConductPenaltyResult

        conduct_id: Union[Unset, str] = UNSET
        if not isinstance(self.conduct_id, Unset):
            conduct_id = str(self.conduct_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        entity_group_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_group_id, Unset):
            entity_group_id = str(self.entity_group_id)

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        venue_id: Union[Unset, str] = UNSET
        if not isinstance(self.venue_id, Unset):
            venue_id = str(self.venue_id)

        venue: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.venue, Unset):
            venue = self.venue.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        season_id: Union[Unset, str] = UNSET
        if not isinstance(self.season_id, Unset):
            season_id = str(self.season_id)

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        competition_id: Union[Unset, str] = UNSET
        if not isinstance(self.competition_id, Unset):
            competition_id = str(self.competition_id)

        competition: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.competition, Unset):
            competition = self.competition.to_dict()

        bib: Union[None, Unset, str]
        if isinstance(self.bib, Unset):
            bib = UNSET
        else:
            bib = self.bib

        location_other: Union[None, Unset, str]
        if isinstance(self.location_other, Unset):
            location_other = UNSET
        else:
            location_other = self.location_other

        event_id: Union[Unset, str] = UNSET
        if not isinstance(self.event_id, Unset):
            event_id = str(self.event_id)

        period_id: Union[Unset, int] = UNSET
        if not isinstance(self.period_id, Unset):
            period_id = self.period_id.value

        section = self.section

        fixture_clock: Union[None, Unset, str]
        if isinstance(self.fixture_clock, Unset):
            fixture_clock = UNSET
        else:
            fixture_clock = self.fixture_clock

        role: Union[None, Unset, str]
        if isinstance(self.role, Unset):
            role = UNSET
        elif isinstance(self.role, ConductModelRoleType1):
            role = self.role.value
        elif isinstance(self.role, ConductModelRoleType2Type1):
            role = self.role.value
        elif isinstance(self.role, ConductModelRoleType3Type1):
            role = self.role.value
        else:
            role = self.role

        date_offence_local: Union[None, Unset, str]
        if isinstance(self.date_offence_local, Unset):
            date_offence_local = UNSET
        elif isinstance(self.date_offence_local, datetime.datetime):
            date_offence_local = self.date_offence_local.isoformat()
        else:
            date_offence_local = self.date_offence_local

        conduct_type: Union[Unset, list[str]] = UNSET
        if not isinstance(self.conduct_type, Unset):
            conduct_type = []
            for conduct_type_item_data in self.conduct_type:
                conduct_type_item = conduct_type_item_data.value
                conduct_type.append(conduct_type_item)

        conduct_notes: Union[None, Unset, str]
        if isinstance(self.conduct_notes, Unset):
            conduct_notes = UNSET
        else:
            conduct_notes = self.conduct_notes

        date_hearing_local: Union[None, Unset, str]
        if isinstance(self.date_hearing_local, Unset):
            date_hearing_local = UNSET
        elif isinstance(self.date_hearing_local, datetime.date):
            date_hearing_local = self.date_hearing_local.isoformat()
        else:
            date_hearing_local = self.date_hearing_local

        hearing_notes: Union[None, Unset, str]
        if isinstance(self.hearing_notes, Unset):
            hearing_notes = UNSET
        else:
            hearing_notes = self.hearing_notes

        hearing_status: Union[None, Unset, str]
        if isinstance(self.hearing_status, Unset):
            hearing_status = UNSET
        elif isinstance(self.hearing_status, ConductModelHearingStatusType1):
            hearing_status = self.hearing_status.value
        elif isinstance(self.hearing_status, ConductModelHearingStatusType2Type1):
            hearing_status = self.hearing_status.value
        elif isinstance(self.hearing_status, ConductModelHearingStatusType3Type1):
            hearing_status = self.hearing_status.value
        else:
            hearing_status = self.hearing_status

        life_sentence = self.life_sentence

        penalty_results: Union[Unset, list[Union[None, dict[str, Any]]]] = UNSET
        if not isinstance(self.penalty_results, Unset):
            penalty_results = []
            for penalty_results_item_data in self.penalty_results:
                penalty_results_item: Union[None, dict[str, Any]]
                if isinstance(penalty_results_item_data, ConductModelConductPenaltyResult):
                    penalty_results_item = penalty_results_item_data.to_dict()
                else:
                    penalty_results_item = penalty_results_item_data
                penalty_results.append(penalty_results_item)

        fine_amount = self.fine_amount

        fine_currency: Union[None, Unset, str]
        if isinstance(self.fine_currency, Unset):
            fine_currency = UNSET
        else:
            fine_currency = self.fine_currency

        fine_status: Union[None, Unset, str]
        if isinstance(self.fine_status, Unset):
            fine_status = UNSET
        elif isinstance(self.fine_status, ConductModelFineStatusType1):
            fine_status = self.fine_status.value
        elif isinstance(self.fine_status, ConductModelFineStatusType2Type1):
            fine_status = self.fine_status.value
        elif isinstance(self.fine_status, ConductModelFineStatusType3Type1):
            fine_status = self.fine_status.value
        else:
            fine_status = self.fine_status

        date_suspended_to: Union[None, Unset, str]
        if isinstance(self.date_suspended_to, Unset):
            date_suspended_to = UNSET
        elif isinstance(self.date_suspended_to, datetime.date):
            date_suspended_to = self.date_suspended_to.isoformat()
        else:
            date_suspended_to = self.date_suspended_to

        date_suspended_from: Union[None, Unset, str]
        if isinstance(self.date_suspended_from, Unset):
            date_suspended_from = UNSET
        elif isinstance(self.date_suspended_from, datetime.date):
            date_suspended_from = self.date_suspended_from.isoformat()
        else:
            date_suspended_from = self.date_suspended_from

        date_fine_paid_local: Union[None, Unset, str]
        if isinstance(self.date_fine_paid_local, Unset):
            date_fine_paid_local = UNSET
        elif isinstance(self.date_fine_paid_local, datetime.date):
            date_fine_paid_local = self.date_fine_paid_local.isoformat()
        else:
            date_fine_paid_local = self.date_fine_paid_local

        status: Union[None, Unset, str]
        if isinstance(self.status, Unset):
            status = UNSET
        elif isinstance(self.status, ConductModelStatusType1):
            status = self.status.value
        elif isinstance(self.status, ConductModelStatusType2Type1):
            status = self.status.value
        elif isinstance(self.status, ConductModelStatusType3Type1):
            status = self.status.value
        else:
            status = self.status

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if conduct_id is not UNSET:
            field_dict["conductId"] = conduct_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if venue_id is not UNSET:
            field_dict["venueId"] = venue_id
        if venue is not UNSET:
            field_dict["venue"] = venue
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if competition_id is not UNSET:
            field_dict["competitionId"] = competition_id
        if competition is not UNSET:
            field_dict["competition"] = competition
        if bib is not UNSET:
            field_dict["bib"] = bib
        if location_other is not UNSET:
            field_dict["locationOther"] = location_other
        if event_id is not UNSET:
            field_dict["eventId"] = event_id
        if period_id is not UNSET:
            field_dict["periodId"] = period_id
        if section is not UNSET:
            field_dict["section"] = section
        if fixture_clock is not UNSET:
            field_dict["fixtureClock"] = fixture_clock
        if role is not UNSET:
            field_dict["role"] = role
        if date_offence_local is not UNSET:
            field_dict["dateOffenceLocal"] = date_offence_local
        if conduct_type is not UNSET:
            field_dict["conductType"] = conduct_type
        if conduct_notes is not UNSET:
            field_dict["conductNotes"] = conduct_notes
        if date_hearing_local is not UNSET:
            field_dict["dateHearingLocal"] = date_hearing_local
        if hearing_notes is not UNSET:
            field_dict["hearingNotes"] = hearing_notes
        if hearing_status is not UNSET:
            field_dict["hearingStatus"] = hearing_status
        if life_sentence is not UNSET:
            field_dict["lifeSentence"] = life_sentence
        if penalty_results is not UNSET:
            field_dict["penaltyResults"] = penalty_results
        if fine_amount is not UNSET:
            field_dict["fineAmount"] = fine_amount
        if fine_currency is not UNSET:
            field_dict["fineCurrency"] = fine_currency
        if fine_status is not UNSET:
            field_dict["fineStatus"] = fine_status
        if date_suspended_to is not UNSET:
            field_dict["dateSuspendedTo"] = date_suspended_to
        if date_suspended_from is not UNSET:
            field_dict["dateSuspendedFrom"] = date_suspended_from
        if date_fine_paid_local is not UNSET:
            field_dict["dateFinePaidLocal"] = date_fine_paid_local
        if status is not UNSET:
            field_dict["status"] = status
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.conduct_model_competition import ConductModelCompetition
        from ..models.conduct_model_conduct_penalty_result import ConductModelConductPenaltyResult
        from ..models.conduct_model_entity import ConductModelEntity
        from ..models.conduct_model_entity_group import ConductModelEntityGroup
        from ..models.conduct_model_fixture import ConductModelFixture
        from ..models.conduct_model_organization import ConductModelOrganization
        from ..models.conduct_model_person import ConductModelPerson
        from ..models.conduct_model_season import ConductModelSeason
        from ..models.conduct_model_venue import ConductModelVenue

        d = dict(src_dict)
        _conduct_id = d.pop("conductId", UNSET)
        conduct_id: Union[Unset, UUID]
        if isinstance(_conduct_id, Unset):
            conduct_id = UNSET
        else:
            conduct_id = UUID(_conduct_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, ConductModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = ConductModelOrganization.from_dict(_organization)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, ConductModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = ConductModelPerson.from_dict(_person)

        _entity_group_id = d.pop("entityGroupId", UNSET)
        entity_group_id: Union[Unset, UUID]
        if isinstance(_entity_group_id, Unset):
            entity_group_id = UNSET
        else:
            entity_group_id = UUID(_entity_group_id)

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, ConductModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = ConductModelEntityGroup.from_dict(_entity_group)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, ConductModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = ConductModelEntity.from_dict(_entity)

        _venue_id = d.pop("venueId", UNSET)
        venue_id: Union[Unset, UUID]
        if isinstance(_venue_id, Unset):
            venue_id = UNSET
        else:
            venue_id = UUID(_venue_id)

        _venue = d.pop("venue", UNSET)
        venue: Union[Unset, ConductModelVenue]
        if isinstance(_venue, Unset):
            venue = UNSET
        else:
            venue = ConductModelVenue.from_dict(_venue)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, ConductModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = ConductModelFixture.from_dict(_fixture)

        _season_id = d.pop("seasonId", UNSET)
        season_id: Union[Unset, UUID]
        if isinstance(_season_id, Unset):
            season_id = UNSET
        else:
            season_id = UUID(_season_id)

        _season = d.pop("season", UNSET)
        season: Union[Unset, ConductModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = ConductModelSeason.from_dict(_season)

        _competition_id = d.pop("competitionId", UNSET)
        competition_id: Union[Unset, UUID]
        if isinstance(_competition_id, Unset):
            competition_id = UNSET
        else:
            competition_id = UUID(_competition_id)

        _competition = d.pop("competition", UNSET)
        competition: Union[Unset, ConductModelCompetition]
        if isinstance(_competition, Unset):
            competition = UNSET
        else:
            competition = ConductModelCompetition.from_dict(_competition)

        def _parse_bib(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        bib = _parse_bib(d.pop("bib", UNSET))

        def _parse_location_other(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        location_other = _parse_location_other(d.pop("locationOther", UNSET))

        _event_id = d.pop("eventId", UNSET)
        event_id: Union[Unset, UUID]
        if isinstance(_event_id, Unset):
            event_id = UNSET
        else:
            event_id = UUID(_event_id)

        _period_id = d.pop("periodId", UNSET)
        period_id: Union[Unset, ConductModelPeriodId]
        if isinstance(_period_id, Unset):
            period_id = UNSET
        else:
            period_id = ConductModelPeriodId(_period_id)

        section = d.pop("section", UNSET)

        def _parse_fixture_clock(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        fixture_clock = _parse_fixture_clock(d.pop("fixtureClock", UNSET))

        def _parse_role(
            data: object,
        ) -> Union[ConductModelRoleType1, ConductModelRoleType2Type1, ConductModelRoleType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                role_type_1 = ConductModelRoleType1(data)

                return role_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                role_type_2_type_1 = ConductModelRoleType2Type1(data)

                return role_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                role_type_3_type_1 = ConductModelRoleType3Type1(data)

                return role_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[ConductModelRoleType1, ConductModelRoleType2Type1, ConductModelRoleType3Type1, None, Unset], data
            )

        role = _parse_role(d.pop("role", UNSET))

        def _parse_date_offence_local(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_offence_local_type_0 = isoparse(data)

                return date_offence_local_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        date_offence_local = _parse_date_offence_local(d.pop("dateOffenceLocal", UNSET))

        conduct_type = []
        _conduct_type = d.pop("conductType", UNSET)
        for conduct_type_item_data in _conduct_type or []:
            conduct_type_item = ConductModelConductTypeItem(conduct_type_item_data)

            conduct_type.append(conduct_type_item)

        def _parse_conduct_notes(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        conduct_notes = _parse_conduct_notes(d.pop("conductNotes", UNSET))

        def _parse_date_hearing_local(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_hearing_local_type_0 = isoparse(data).date()

                return date_hearing_local_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_hearing_local = _parse_date_hearing_local(d.pop("dateHearingLocal", UNSET))

        def _parse_hearing_notes(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        hearing_notes = _parse_hearing_notes(d.pop("hearingNotes", UNSET))

        def _parse_hearing_status(
            data: object,
        ) -> Union[
            ConductModelHearingStatusType1,
            ConductModelHearingStatusType2Type1,
            ConductModelHearingStatusType3Type1,
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                hearing_status_type_1 = ConductModelHearingStatusType1(data)

                return hearing_status_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                hearing_status_type_2_type_1 = ConductModelHearingStatusType2Type1(data)

                return hearing_status_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                hearing_status_type_3_type_1 = ConductModelHearingStatusType3Type1(data)

                return hearing_status_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    ConductModelHearingStatusType1,
                    ConductModelHearingStatusType2Type1,
                    ConductModelHearingStatusType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        hearing_status = _parse_hearing_status(d.pop("hearingStatus", UNSET))

        life_sentence = d.pop("lifeSentence", UNSET)

        penalty_results = []
        _penalty_results = d.pop("penaltyResults", UNSET)
        for penalty_results_item_data in _penalty_results or []:

            def _parse_penalty_results_item(data: object) -> Union["ConductModelConductPenaltyResult", None]:
                if data is None:
                    return data
                try:
                    if not isinstance(data, dict):
                        raise TypeError()
                    penalty_results_item_type_0 = ConductModelConductPenaltyResult.from_dict(data)

                    return penalty_results_item_type_0
                except:  # noqa: E722
                    pass
                return cast(Union["ConductModelConductPenaltyResult", None], data)

            penalty_results_item = _parse_penalty_results_item(penalty_results_item_data)

            penalty_results.append(penalty_results_item)

        fine_amount = d.pop("fineAmount", UNSET)

        def _parse_fine_currency(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        fine_currency = _parse_fine_currency(d.pop("fineCurrency", UNSET))

        def _parse_fine_status(
            data: object,
        ) -> Union[
            ConductModelFineStatusType1, ConductModelFineStatusType2Type1, ConductModelFineStatusType3Type1, None, Unset
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                fine_status_type_1 = ConductModelFineStatusType1(data)

                return fine_status_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                fine_status_type_2_type_1 = ConductModelFineStatusType2Type1(data)

                return fine_status_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                fine_status_type_3_type_1 = ConductModelFineStatusType3Type1(data)

                return fine_status_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[
                    ConductModelFineStatusType1,
                    ConductModelFineStatusType2Type1,
                    ConductModelFineStatusType3Type1,
                    None,
                    Unset,
                ],
                data,
            )

        fine_status = _parse_fine_status(d.pop("fineStatus", UNSET))

        def _parse_date_suspended_to(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_suspended_to_type_0 = isoparse(data).date()

                return date_suspended_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_suspended_to = _parse_date_suspended_to(d.pop("dateSuspendedTo", UNSET))

        def _parse_date_suspended_from(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_suspended_from_type_0 = isoparse(data).date()

                return date_suspended_from_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_suspended_from = _parse_date_suspended_from(d.pop("dateSuspendedFrom", UNSET))

        def _parse_date_fine_paid_local(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_fine_paid_local_type_0 = isoparse(data).date()

                return date_fine_paid_local_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_fine_paid_local = _parse_date_fine_paid_local(d.pop("dateFinePaidLocal", UNSET))

        def _parse_status(
            data: object,
        ) -> Union[ConductModelStatusType1, ConductModelStatusType2Type1, ConductModelStatusType3Type1, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_1 = ConductModelStatusType1(data)

                return status_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_2_type_1 = ConductModelStatusType2Type1(data)

                return status_type_2_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_3_type_1 = ConductModelStatusType3Type1(data)

                return status_type_3_type_1
            except:  # noqa: E722
                pass
            return cast(
                Union[ConductModelStatusType1, ConductModelStatusType2Type1, ConductModelStatusType3Type1, None, Unset],
                data,
            )

        status = _parse_status(d.pop("status", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        conduct_model = cls(
            conduct_id=conduct_id,
            organization_id=organization_id,
            organization=organization,
            person_id=person_id,
            person=person,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            entity_id=entity_id,
            entity=entity,
            venue_id=venue_id,
            venue=venue,
            fixture_id=fixture_id,
            fixture=fixture,
            season_id=season_id,
            season=season,
            competition_id=competition_id,
            competition=competition,
            bib=bib,
            location_other=location_other,
            event_id=event_id,
            period_id=period_id,
            section=section,
            fixture_clock=fixture_clock,
            role=role,
            date_offence_local=date_offence_local,
            conduct_type=conduct_type,
            conduct_notes=conduct_notes,
            date_hearing_local=date_hearing_local,
            hearing_notes=hearing_notes,
            hearing_status=hearing_status,
            life_sentence=life_sentence,
            penalty_results=penalty_results,
            fine_amount=fine_amount,
            fine_currency=fine_currency,
            fine_status=fine_status,
            date_suspended_to=date_suspended_to,
            date_suspended_from=date_suspended_from,
            date_fine_paid_local=date_fine_paid_local,
            status=status,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return conduct_model



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.fixture_pbp_event_model_class import FixturePBPEventModelClass
from ..models.fixture_pbp_event_model_period_id import FixturePBPEventModelPeriodId
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.fixture_pbp_event_model_current_scores import FixturePBPEventModelCurrentScores
    from ..models.fixture_pbp_event_model_entity import FixturePBPEventModelEntity
    from ..models.fixture_pbp_event_model_fixture import FixturePBPEventModelFixture
    from ..models.fixture_pbp_event_model_organization import FixturePBPEventModelOrganization
    from ..models.fixture_pbp_event_model_person import FixturePBPEventModelPerson


T = TypeVar("T", bound="FixturePBPEventModel")


@_attrs_define
class FixturePBPEventModel:
    """
    Attributes:
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, FixturePBPEventModelOrganization]): The organization that this Fixture PBP Event
            belongs to
        fixture_id (Union[Unset, UUID]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, FixturePBPEventModelFixture]): The match
        period_id (Union[Unset, FixturePBPEventModelPeriodId]): The identifier for the period
            >- `1` Period 1
            >- `2` Period 2
            >- `10` Extra time 1 period 1
            >- `11` Extra time 1 period 2
            >- `12` Extra time 2 period 1
            >- `13` Extra time 2 period 2
            >- `14` Shoot Out
        section (Union[Unset, str]): The section of the period (sub-period)
        events (Union[Unset, Any]):
        class_ (Union[Unset, FixturePBPEventModelClass]): The class of the event
            >- `clock` Information about the current status of the clock match
            >- `sport` A sporting action that relates to the running of the match
             Default: FixturePBPEventModelClass.SPORT. Example: sport.
        event_type (Union[Unset, str]): See [Event
            Types](http://developer.connect.sportradar.com/datacore/streaming.html#section/Message-Types/event) for more
            information Example: substitution.
        event_id (Union[Unset, UUID]): Unique identifier of this event Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        play_id (Union[Unset, UUID]): Unique identifier of this play (group of events) Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_id (Union[Unset, UUID]): The unique identifier of the team Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, FixturePBPEventModelEntity]): The team information
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, FixturePBPEventModelPerson]): The person information
        sub_type (Union[Unset, str]): The Sub Type of event. See <b>Streaming API</b> documenation for more information.
            Example: out.
        options (Union[Unset, Any]):
        received (Union[Unset, int]): The UNIX timestamp when the event was received.
        status (Union[Unset, str]): The status of this message.  Options are `added` (Default); `updated` - meaning the
            content of this event has been edited; `deleted` - meaning this event has been deleted; `enriched` - meaning
            further information has been added to the event (not changed).
        success (Union[Unset, bool]): Whether the action was successful
        x (Union[Unset, float]): The x co-ordinate of the event. Represented as percentage from left (0) to right (100).
            Example: 56.
        y (Union[Unset, float]): The y co-ordinate of the event. Represented as precentage from top (0) to bottom (100).
            Example: 23.
        z (Union[Unset, float]): The z co-ordinate of the event. Represented as precentage from ground (0) to ceiling
            (100). Example: 10.
        clock (Union[Unset, str]): The time on the clock when the event occurred. ISO 8601 format. PTmmMss.ccS Example:
            PT12M34.5S.
        shot_clock (Union[Unset, str]): The time on the shot clock when the event occurred. ISO 8601 format. PTss.ccS
            Example: PT34.2S.
        event_time (Union[Unset, datetime.datetime]): The date/time (UTC) this event occurred. For inserted actions,
            this should be the time the action would have occurred, not the time of insertion. Example:
            2016-09-08T02:02:00Z.
        official_id (Union[Unset, UUID]): The unique ID of the official making this decision Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        zone (Union[Unset, str]): See [Event Types]() for more information
        scores (Union['FixturePBPEventModelCurrentScores', None, Unset]): The current scores
        timestamp (Union[Unset, datetime.datetime]): The date/time (UTC) this event was sent. Example:
            2016-09-08T02:02:00Z.
        client_type (Union[Unset, str]): Type of the client that sent the event Example: InGame.
        client_id (Union[Unset, str]): ID of the client that sent the event Example: InGame:0.9.
        sport (Union[Unset, str]): Sport one letter code Example: h.
        topic (Union[Unset, str]): MQTT topic where the event was sent Example:
            s/h/h1s44/3c467c99-9e5d-11ee-91d0-2b012330fcf5/w/e.
        type_ (Union[Unset, str]): Type of the event message Example: event.
        sequence (Union[None, Unset, int]): Client event sequence number Example: 10.
    """

    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "FixturePBPEventModelOrganization"] = UNSET
    fixture_id: Union[Unset, UUID] = UNSET
    fixture: Union[Unset, "FixturePBPEventModelFixture"] = UNSET
    period_id: Union[Unset, FixturePBPEventModelPeriodId] = UNSET
    section: Union[Unset, str] = UNSET
    events: Union[Unset, Any] = UNSET
    class_: Union[Unset, FixturePBPEventModelClass] = FixturePBPEventModelClass.SPORT
    event_type: Union[Unset, str] = UNSET
    event_id: Union[Unset, UUID] = UNSET
    play_id: Union[Unset, UUID] = UNSET
    entity_id: Union[Unset, UUID] = UNSET
    entity: Union[Unset, "FixturePBPEventModelEntity"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "FixturePBPEventModelPerson"] = UNSET
    sub_type: Union[Unset, str] = UNSET
    options: Union[Unset, Any] = UNSET
    received: Union[Unset, int] = UNSET
    status: Union[Unset, str] = UNSET
    success: Union[Unset, bool] = UNSET
    x: Union[Unset, float] = UNSET
    y: Union[Unset, float] = UNSET
    z: Union[Unset, float] = UNSET
    clock: Union[Unset, str] = UNSET
    shot_clock: Union[Unset, str] = UNSET
    event_time: Union[Unset, datetime.datetime] = UNSET
    official_id: Union[Unset, UUID] = UNSET
    zone: Union[Unset, str] = UNSET
    scores: Union["FixturePBPEventModelCurrentScores", None, Unset] = UNSET
    timestamp: Union[Unset, datetime.datetime] = UNSET
    client_type: Union[Unset, str] = UNSET
    client_id: Union[Unset, str] = UNSET
    sport: Union[Unset, str] = UNSET
    topic: Union[Unset, str] = UNSET
    type_: Union[Unset, str] = UNSET
    sequence: Union[None, Unset, int] = UNSET

    def to_dict(self) -> dict[str, Any]:
        from ..models.fixture_pbp_event_model_current_scores import FixturePBPEventModelCurrentScores

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        fixture_id: Union[Unset, str] = UNSET
        if not isinstance(self.fixture_id, Unset):
            fixture_id = str(self.fixture_id)

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        period_id: Union[Unset, int] = UNSET
        if not isinstance(self.period_id, Unset):
            period_id = self.period_id.value

        section = self.section

        events = self.events

        class_: Union[Unset, str] = UNSET
        if not isinstance(self.class_, Unset):
            class_ = self.class_.value

        event_type = self.event_type

        event_id: Union[Unset, str] = UNSET
        if not isinstance(self.event_id, Unset):
            event_id = str(self.event_id)

        play_id: Union[Unset, str] = UNSET
        if not isinstance(self.play_id, Unset):
            play_id = str(self.play_id)

        entity_id: Union[Unset, str] = UNSET
        if not isinstance(self.entity_id, Unset):
            entity_id = str(self.entity_id)

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        sub_type = self.sub_type

        options = self.options

        received = self.received

        status = self.status

        success = self.success

        x = self.x

        y = self.y

        z = self.z

        clock = self.clock

        shot_clock = self.shot_clock

        event_time: Union[Unset, str] = UNSET
        if not isinstance(self.event_time, Unset):
            event_time = self.event_time.isoformat()

        official_id: Union[Unset, str] = UNSET
        if not isinstance(self.official_id, Unset):
            official_id = str(self.official_id)

        zone = self.zone

        scores: Union[None, Unset, dict[str, Any]]
        if isinstance(self.scores, Unset):
            scores = UNSET
        elif isinstance(self.scores, FixturePBPEventModelCurrentScores):
            scores = self.scores.to_dict()
        else:
            scores = self.scores

        timestamp: Union[Unset, str] = UNSET
        if not isinstance(self.timestamp, Unset):
            timestamp = self.timestamp.isoformat()

        client_type = self.client_type

        client_id = self.client_id

        sport = self.sport

        topic = self.topic

        type_ = self.type_

        sequence: Union[None, Unset, int]
        if isinstance(self.sequence, Unset):
            sequence = UNSET
        else:
            sequence = self.sequence

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if period_id is not UNSET:
            field_dict["periodId"] = period_id
        if section is not UNSET:
            field_dict["section"] = section
        if events is not UNSET:
            field_dict["events"] = events
        if class_ is not UNSET:
            field_dict["class"] = class_
        if event_type is not UNSET:
            field_dict["eventType"] = event_type
        if event_id is not UNSET:
            field_dict["eventId"] = event_id
        if play_id is not UNSET:
            field_dict["playId"] = play_id
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if sub_type is not UNSET:
            field_dict["subType"] = sub_type
        if options is not UNSET:
            field_dict["options"] = options
        if received is not UNSET:
            field_dict["received"] = received
        if status is not UNSET:
            field_dict["status"] = status
        if success is not UNSET:
            field_dict["success"] = success
        if x is not UNSET:
            field_dict["x"] = x
        if y is not UNSET:
            field_dict["y"] = y
        if z is not UNSET:
            field_dict["z"] = z
        if clock is not UNSET:
            field_dict["clock"] = clock
        if shot_clock is not UNSET:
            field_dict["shotClock"] = shot_clock
        if event_time is not UNSET:
            field_dict["eventTime"] = event_time
        if official_id is not UNSET:
            field_dict["officialId"] = official_id
        if zone is not UNSET:
            field_dict["zone"] = zone
        if scores is not UNSET:
            field_dict["scores"] = scores
        if timestamp is not UNSET:
            field_dict["timestamp"] = timestamp
        if client_type is not UNSET:
            field_dict["clientType"] = client_type
        if client_id is not UNSET:
            field_dict["clientId"] = client_id
        if sport is not UNSET:
            field_dict["sport"] = sport
        if topic is not UNSET:
            field_dict["topic"] = topic
        if type_ is not UNSET:
            field_dict["type"] = type_
        if sequence is not UNSET:
            field_dict["sequence"] = sequence

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.fixture_pbp_event_model_current_scores import FixturePBPEventModelCurrentScores
        from ..models.fixture_pbp_event_model_entity import FixturePBPEventModelEntity
        from ..models.fixture_pbp_event_model_fixture import FixturePBPEventModelFixture
        from ..models.fixture_pbp_event_model_organization import FixturePBPEventModelOrganization
        from ..models.fixture_pbp_event_model_person import FixturePBPEventModelPerson

        d = dict(src_dict)
        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, FixturePBPEventModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = FixturePBPEventModelOrganization.from_dict(_organization)

        _fixture_id = d.pop("fixtureId", UNSET)
        fixture_id: Union[Unset, UUID]
        if isinstance(_fixture_id, Unset):
            fixture_id = UNSET
        else:
            fixture_id = UUID(_fixture_id)

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, FixturePBPEventModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = FixturePBPEventModelFixture.from_dict(_fixture)

        _period_id = d.pop("periodId", UNSET)
        period_id: Union[Unset, FixturePBPEventModelPeriodId]
        if isinstance(_period_id, Unset):
            period_id = UNSET
        else:
            period_id = FixturePBPEventModelPeriodId(_period_id)

        section = d.pop("section", UNSET)

        events = d.pop("events", UNSET)

        _class_ = d.pop("class", UNSET)
        class_: Union[Unset, FixturePBPEventModelClass]
        if isinstance(_class_, Unset):
            class_ = UNSET
        else:
            class_ = FixturePBPEventModelClass(_class_)

        event_type = d.pop("eventType", UNSET)

        _event_id = d.pop("eventId", UNSET)
        event_id: Union[Unset, UUID]
        if isinstance(_event_id, Unset):
            event_id = UNSET
        else:
            event_id = UUID(_event_id)

        _play_id = d.pop("playId", UNSET)
        play_id: Union[Unset, UUID]
        if isinstance(_play_id, Unset):
            play_id = UNSET
        else:
            play_id = UUID(_play_id)

        _entity_id = d.pop("entityId", UNSET)
        entity_id: Union[Unset, UUID]
        if isinstance(_entity_id, Unset):
            entity_id = UNSET
        else:
            entity_id = UUID(_entity_id)

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, FixturePBPEventModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = FixturePBPEventModelEntity.from_dict(_entity)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, FixturePBPEventModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = FixturePBPEventModelPerson.from_dict(_person)

        sub_type = d.pop("subType", UNSET)

        options = d.pop("options", UNSET)

        received = d.pop("received", UNSET)

        status = d.pop("status", UNSET)

        success = d.pop("success", UNSET)

        x = d.pop("x", UNSET)

        y = d.pop("y", UNSET)

        z = d.pop("z", UNSET)

        clock = d.pop("clock", UNSET)

        shot_clock = d.pop("shotClock", UNSET)

        _event_time = d.pop("eventTime", UNSET)
        event_time: Union[Unset, datetime.datetime]
        if isinstance(_event_time, Unset):
            event_time = UNSET
        else:
            event_time = isoparse(_event_time)

        _official_id = d.pop("officialId", UNSET)
        official_id: Union[Unset, UUID]
        if isinstance(_official_id, Unset):
            official_id = UNSET
        else:
            official_id = UUID(_official_id)

        zone = d.pop("zone", UNSET)

        def _parse_scores(data: object) -> Union["FixturePBPEventModelCurrentScores", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                scores_type_0 = FixturePBPEventModelCurrentScores.from_dict(data)

                return scores_type_0
            except:  # noqa: E722
                pass
            return cast(Union["FixturePBPEventModelCurrentScores", None, Unset], data)

        scores = _parse_scores(d.pop("scores", UNSET))

        _timestamp = d.pop("timestamp", UNSET)
        timestamp: Union[Unset, datetime.datetime]
        if isinstance(_timestamp, Unset):
            timestamp = UNSET
        else:
            timestamp = isoparse(_timestamp)

        client_type = d.pop("clientType", UNSET)

        client_id = d.pop("clientId", UNSET)

        sport = d.pop("sport", UNSET)

        topic = d.pop("topic", UNSET)

        type_ = d.pop("type", UNSET)

        def _parse_sequence(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        sequence = _parse_sequence(d.pop("sequence", UNSET))

        fixture_pbp_event_model = cls(
            organization_id=organization_id,
            organization=organization,
            fixture_id=fixture_id,
            fixture=fixture,
            period_id=period_id,
            section=section,
            events=events,
            class_=class_,
            event_type=event_type,
            event_id=event_id,
            play_id=play_id,
            entity_id=entity_id,
            entity=entity,
            person_id=person_id,
            person=person,
            sub_type=sub_type,
            options=options,
            received=received,
            status=status,
            success=success,
            x=x,
            y=y,
            z=z,
            clock=clock,
            shot_clock=shot_clock,
            event_time=event_time,
            official_id=official_id,
            zone=zone,
            scores=scores,
            timestamp=timestamp,
            client_type=client_type,
            client_id=client_id,
            sport=sport,
            topic=topic,
            type_=type_,
            sequence=sequence,
        )

        return fixture_pbp_event_model



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.error_list_model import ErrorListModel


T = TypeVar("T", bound="ErrorModel")


@_attrs_define
class ErrorModel:
    """
    Attributes:
        code (Union[Unset, int]): HTTP Error code indicating the type of error.  If there are multiple errors, then this
            will be the code of the first one. Example: 400.
        message (Union[Unset, str]): A message indicating the reason for the error. If there are multiple errors, then
            this is the message for the first one. Example: Field 'dob' must contain a valid date.
        errors (Union[Unset, list['ErrorListModel']]):
    """

    code: Union[Unset, int] = UNSET
    message: Union[Unset, str] = UNSET
    errors: Union[Unset, list["ErrorListModel"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        code = self.code

        message = self.message

        errors: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.errors, Unset):
            errors = []
            for errors_item_data in self.errors:
                errors_item = errors_item_data.to_dict()
                errors.append(errors_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if code is not UNSET:
            field_dict["code"] = code
        if message is not UNSET:
            field_dict["message"] = message
        if errors is not UNSET:
            field_dict["errors"] = errors

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.error_list_model import ErrorListModel

        d = dict(src_dict)
        code = d.pop("code", UNSET)

        message = d.pop("message", UNSET)

        errors = []
        _errors = d.pop("errors", UNSET)
        for errors_item_data in _errors or []:
            errors_item = ErrorListModel.from_dict(errors_item_data)

            errors.append(errors_item)

        error_model = cls(
            code=code,
            message=message,
            errors=errors,
        )

        error_model.additional_properties = d
        return error_model

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class SeriesModelSeasonSeriesCompetitorSeriesResult(str, Enum):
    DRAW = "DRAW"
    LOST = "LOST"
    PENDING = "PENDING"
    WON = "WON"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.role_model_role_type_1 import RoleModelRoleType1
from ..models.role_model_status import RoleModelStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.role_model_entity import RoleModelEntity
    from ..models.role_model_entity_group import RoleModelEntityGroup
    from ..models.role_model_fixture import RoleModelFixture
    from ..models.role_model_organization import RoleModelOrganization
    from ..models.role_model_person import RoleModelPerson
    from ..models.role_model_season import RoleModelSeason


T = TypeVar("T", bound="RoleModel")


@_attrs_define
class RoleModel:
    """
    Attributes:
        role_id (Union[Unset, UUID]): The unique identifier of the role Example: 009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        organization_id (Union[Unset, str]): The unique identifier of the organization Example: 9.
        organization (Union[Unset, RoleModelOrganization]): The organization that this role belongs to
        entity_group_id (Union[None, UUID, Unset]): The club that this team belongs to Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity_group (Union[Unset, RoleModelEntityGroup]): The club that this team belongs to
        entity_id (Union[None, UUID, Unset]): The unique identifier of the team Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        entity (Union[Unset, RoleModelEntity]): The team information
        season_id (Union[None, UUID, Unset]): The unique identifier of the season Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        season (Union[Unset, RoleModelSeason]): The season linked to this record
        fixture_id (Union[None, UUID, Unset]): The unique identifier of the match Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        fixture (Union[Unset, RoleModelFixture]): The match
        person_id (Union[Unset, UUID]): The unique identifier of the person Example:
            009e9276-5c80-11e8-9c2d-fa7ae01bbebc.
        person (Union[Unset, RoleModelPerson]): The person information
        status (Union[Unset, RoleModelStatus]): Status
            >- `ACTIVE` Active
            >- `INACTIVE` Inactive
            >- `PENDING` Pending
             Example: ACTIVE.
        date_from (Union[None, Unset, datetime.date]): Date the role started (Not for a role within a match) Example:
            1978-08-24.
        date_to (Union[None, Unset, datetime.date]): Date the role ended (Not for a role within a match) Example:
            1978-08-24.
        bib (Union[None, Unset, str]): The number displayed on the jersey Example: 34.
        role_number (Union[None, Unset, int]): Number within the role. eg: Assistant Coach 2 Example: 1.
        role (Union[None, RoleModelRoleType1, Unset]): Role
            >- None None
            >- `ASSISTANT_REFEREE_1` Assistant Referee 1
            >- `ASSISTANT_REFEREE_2` Assistant Referee 2
            >- `CLUB_IT_OFFICER` Club IT Officer
            >- `CLUB_OFFICIAL` Club Official
            >- `CLUB_OFFICIAL_ASSISTANT` Substitute for contact person of club
            >- `COACH` Coach
            >- `COACH_ASSISTANT` Coach Assistant
            >- `COACH_HEAD` Coach Head
            >- `DELEGATE` Delegate
            >- `DIRECTOR` Director
            >- `LIAISON_OFFICER` Liaison Officer
            >- `MATCH_LIAISON` Match Liaison
            >- `MATCH_SUPERVISOR` Match Supervisor
            >- `MEDIA_OFFICER` Media Officer
            >- `OFFICE_STAFF` Office Staff
            >- `OFFICIAL_A` Official A
            >- `OFFICIAL_B` Official B
            >- `OFFICIAL_C` Official C
            >- `OFFICIAL_D` Official D
            >- `OFFICIAL_E` Official E
            >- `PLAYER_CONTRACT_MANAGER` Player Contract Manager
            >- `REFEREE` Referee
            >- `REFEREE_LIAISON` Referee Liaison
            >- `REFEREE_OBSERVER` Referee Observer
            >- `REFEREE_OBSERVER_LIAISON` Referee Observer Liaison
            >- `SCOREKEEPER` Scorekeeper
            >- `SCOUT_1` Scout 1
            >- `SCOUT_2` Scout 2
            >- `SCOUT_3` Scout 3
            >- `SCOUT_SUPERVISOR` Scout Supervisor
            >- `SECRETARY` Secretary
            >- `SPORT_DIRECTOR` Sporting Director
            >- `TEAM_COORDINATOR` Team Coordinator
            >- `TIMEKEEPER` Timekeeper
            >- `TRAINER` Trainer
            >- `YOUTH_COORDINATOR` Youth Coordinator
             Example: COACH.
        role_sub_type (Union[None, Unset, str]): Role sub type Example: Offensive Coach.
        external_id (Union[None, Unset, str]): The Id of the data as set by the provider of the data Example: A123.
        updated (Union[Unset, datetime.datetime]): Date/time last modified. In UTC
        added (Union[Unset, datetime.datetime]): Date/time added. In UTC
    """

    role_id: Union[Unset, UUID] = UNSET
    organization_id: Union[Unset, str] = UNSET
    organization: Union[Unset, "RoleModelOrganization"] = UNSET
    entity_group_id: Union[None, UUID, Unset] = UNSET
    entity_group: Union[Unset, "RoleModelEntityGroup"] = UNSET
    entity_id: Union[None, UUID, Unset] = UNSET
    entity: Union[Unset, "RoleModelEntity"] = UNSET
    season_id: Union[None, UUID, Unset] = UNSET
    season: Union[Unset, "RoleModelSeason"] = UNSET
    fixture_id: Union[None, UUID, Unset] = UNSET
    fixture: Union[Unset, "RoleModelFixture"] = UNSET
    person_id: Union[Unset, UUID] = UNSET
    person: Union[Unset, "RoleModelPerson"] = UNSET
    status: Union[Unset, RoleModelStatus] = UNSET
    date_from: Union[None, Unset, datetime.date] = UNSET
    date_to: Union[None, Unset, datetime.date] = UNSET
    bib: Union[None, Unset, str] = UNSET
    role_number: Union[None, Unset, int] = UNSET
    role: Union[None, RoleModelRoleType1, Unset] = UNSET
    role_sub_type: Union[None, Unset, str] = UNSET
    external_id: Union[None, Unset, str] = UNSET
    updated: Union[Unset, datetime.datetime] = UNSET
    added: Union[Unset, datetime.datetime] = UNSET

    def to_dict(self) -> dict[str, Any]:
        role_id: Union[Unset, str] = UNSET
        if not isinstance(self.role_id, Unset):
            role_id = str(self.role_id)

        organization_id = self.organization_id

        organization: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.organization, Unset):
            organization = self.organization.to_dict()

        entity_group_id: Union[None, Unset, str]
        if isinstance(self.entity_group_id, Unset):
            entity_group_id = UNSET
        elif isinstance(self.entity_group_id, UUID):
            entity_group_id = str(self.entity_group_id)
        else:
            entity_group_id = self.entity_group_id

        entity_group: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity_group, Unset):
            entity_group = self.entity_group.to_dict()

        entity_id: Union[None, Unset, str]
        if isinstance(self.entity_id, Unset):
            entity_id = UNSET
        elif isinstance(self.entity_id, UUID):
            entity_id = str(self.entity_id)
        else:
            entity_id = self.entity_id

        entity: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.entity, Unset):
            entity = self.entity.to_dict()

        season_id: Union[None, Unset, str]
        if isinstance(self.season_id, Unset):
            season_id = UNSET
        elif isinstance(self.season_id, UUID):
            season_id = str(self.season_id)
        else:
            season_id = self.season_id

        season: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.season, Unset):
            season = self.season.to_dict()

        fixture_id: Union[None, Unset, str]
        if isinstance(self.fixture_id, Unset):
            fixture_id = UNSET
        elif isinstance(self.fixture_id, UUID):
            fixture_id = str(self.fixture_id)
        else:
            fixture_id = self.fixture_id

        fixture: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fixture, Unset):
            fixture = self.fixture.to_dict()

        person_id: Union[Unset, str] = UNSET
        if not isinstance(self.person_id, Unset):
            person_id = str(self.person_id)

        person: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.person, Unset):
            person = self.person.to_dict()

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        date_from: Union[None, Unset, str]
        if isinstance(self.date_from, Unset):
            date_from = UNSET
        elif isinstance(self.date_from, datetime.date):
            date_from = self.date_from.isoformat()
        else:
            date_from = self.date_from

        date_to: Union[None, Unset, str]
        if isinstance(self.date_to, Unset):
            date_to = UNSET
        elif isinstance(self.date_to, datetime.date):
            date_to = self.date_to.isoformat()
        else:
            date_to = self.date_to

        bib: Union[None, Unset, str]
        if isinstance(self.bib, Unset):
            bib = UNSET
        else:
            bib = self.bib

        role_number: Union[None, Unset, int]
        if isinstance(self.role_number, Unset):
            role_number = UNSET
        else:
            role_number = self.role_number

        role: Union[None, Unset, str]
        if isinstance(self.role, Unset):
            role = UNSET
        elif isinstance(self.role, RoleModelRoleType1):
            role = self.role.value
        else:
            role = self.role

        role_sub_type: Union[None, Unset, str]
        if isinstance(self.role_sub_type, Unset):
            role_sub_type = UNSET
        else:
            role_sub_type = self.role_sub_type

        external_id: Union[None, Unset, str]
        if isinstance(self.external_id, Unset):
            external_id = UNSET
        else:
            external_id = self.external_id

        updated: Union[Unset, str] = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        added: Union[Unset, str] = UNSET
        if not isinstance(self.added, Unset):
            added = self.added.isoformat()

        field_dict: dict[str, Any] = {}

        field_dict.update({})
        if role_id is not UNSET:
            field_dict["roleId"] = role_id
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if organization is not UNSET:
            field_dict["organization"] = organization
        if entity_group_id is not UNSET:
            field_dict["entityGroupId"] = entity_group_id
        if entity_group is not UNSET:
            field_dict["entityGroup"] = entity_group
        if entity_id is not UNSET:
            field_dict["entityId"] = entity_id
        if entity is not UNSET:
            field_dict["entity"] = entity
        if season_id is not UNSET:
            field_dict["seasonId"] = season_id
        if season is not UNSET:
            field_dict["season"] = season
        if fixture_id is not UNSET:
            field_dict["fixtureId"] = fixture_id
        if fixture is not UNSET:
            field_dict["fixture"] = fixture
        if person_id is not UNSET:
            field_dict["personId"] = person_id
        if person is not UNSET:
            field_dict["person"] = person
        if status is not UNSET:
            field_dict["status"] = status
        if date_from is not UNSET:
            field_dict["dateFrom"] = date_from
        if date_to is not UNSET:
            field_dict["dateTo"] = date_to
        if bib is not UNSET:
            field_dict["bib"] = bib
        if role_number is not UNSET:
            field_dict["roleNumber"] = role_number
        if role is not UNSET:
            field_dict["role"] = role
        if role_sub_type is not UNSET:
            field_dict["roleSubType"] = role_sub_type
        if external_id is not UNSET:
            field_dict["externalId"] = external_id
        if updated is not UNSET:
            field_dict["updated"] = updated
        if added is not UNSET:
            field_dict["added"] = added

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.role_model_entity import RoleModelEntity
        from ..models.role_model_entity_group import RoleModelEntityGroup
        from ..models.role_model_fixture import RoleModelFixture
        from ..models.role_model_organization import RoleModelOrganization
        from ..models.role_model_person import RoleModelPerson
        from ..models.role_model_season import RoleModelSeason

        d = dict(src_dict)
        _role_id = d.pop("roleId", UNSET)
        role_id: Union[Unset, UUID]
        if isinstance(_role_id, Unset):
            role_id = UNSET
        else:
            role_id = UUID(_role_id)

        organization_id = d.pop("organizationId", UNSET)

        _organization = d.pop("organization", UNSET)
        organization: Union[Unset, RoleModelOrganization]
        if isinstance(_organization, Unset):
            organization = UNSET
        else:
            organization = RoleModelOrganization.from_dict(_organization)

        def _parse_entity_group_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_group_id_type_0 = UUID(data)

                return entity_group_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_group_id = _parse_entity_group_id(d.pop("entityGroupId", UNSET))

        _entity_group = d.pop("entityGroup", UNSET)
        entity_group: Union[Unset, RoleModelEntityGroup]
        if isinstance(_entity_group, Unset):
            entity_group = UNSET
        else:
            entity_group = RoleModelEntityGroup.from_dict(_entity_group)

        def _parse_entity_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                entity_id_type_0 = UUID(data)

                return entity_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        entity_id = _parse_entity_id(d.pop("entityId", UNSET))

        _entity = d.pop("entity", UNSET)
        entity: Union[Unset, RoleModelEntity]
        if isinstance(_entity, Unset):
            entity = UNSET
        else:
            entity = RoleModelEntity.from_dict(_entity)

        def _parse_season_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                season_id_type_0 = UUID(data)

                return season_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        season_id = _parse_season_id(d.pop("seasonId", UNSET))

        _season = d.pop("season", UNSET)
        season: Union[Unset, RoleModelSeason]
        if isinstance(_season, Unset):
            season = UNSET
        else:
            season = RoleModelSeason.from_dict(_season)

        def _parse_fixture_id(data: object) -> Union[None, UUID, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                fixture_id_type_0 = UUID(data)

                return fixture_id_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, UUID, Unset], data)

        fixture_id = _parse_fixture_id(d.pop("fixtureId", UNSET))

        _fixture = d.pop("fixture", UNSET)
        fixture: Union[Unset, RoleModelFixture]
        if isinstance(_fixture, Unset):
            fixture = UNSET
        else:
            fixture = RoleModelFixture.from_dict(_fixture)

        _person_id = d.pop("personId", UNSET)
        person_id: Union[Unset, UUID]
        if isinstance(_person_id, Unset):
            person_id = UNSET
        else:
            person_id = UUID(_person_id)

        _person = d.pop("person", UNSET)
        person: Union[Unset, RoleModelPerson]
        if isinstance(_person, Unset):
            person = UNSET
        else:
            person = RoleModelPerson.from_dict(_person)

        _status = d.pop("status", UNSET)
        status: Union[Unset, RoleModelStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = RoleModelStatus(_status)

        def _parse_date_from(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_from_type_0 = isoparse(data).date()

                return date_from_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_from = _parse_date_from(d.pop("dateFrom", UNSET))

        def _parse_date_to(data: object) -> Union[None, Unset, datetime.date]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                date_to_type_0 = isoparse(data).date()

                return date_to_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.date], data)

        date_to = _parse_date_to(d.pop("dateTo", UNSET))

        def _parse_bib(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        bib = _parse_bib(d.pop("bib", UNSET))

        def _parse_role_number(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        role_number = _parse_role_number(d.pop("roleNumber", UNSET))

        def _parse_role(data: object) -> Union[None, RoleModelRoleType1, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                role_type_1 = RoleModelRoleType1(data)

                return role_type_1
            except:  # noqa: E722
                pass
            return cast(Union[None, RoleModelRoleType1, Unset], data)

        role = _parse_role(d.pop("role", UNSET))

        def _parse_role_sub_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        role_sub_type = _parse_role_sub_type(d.pop("roleSubType", UNSET))

        def _parse_external_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        external_id = _parse_external_id(d.pop("externalId", UNSET))

        _updated = d.pop("updated", UNSET)
        updated: Union[Unset, datetime.datetime]
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _added = d.pop("added", UNSET)
        added: Union[Unset, datetime.datetime]
        if isinstance(_added, Unset):
            added = UNSET
        else:
            added = isoparse(_added)

        role_model = cls(
            role_id=role_id,
            organization_id=organization_id,
            organization=organization,
            entity_group_id=entity_group_id,
            entity_group=entity_group,
            entity_id=entity_id,
            entity=entity,
            season_id=season_id,
            season=season,
            fixture_id=fixture_id,
            fixture=fixture,
            person_id=person_id,
            person=person,
            status=status,
            date_from=date_from,
            date_to=date_to,
            bib=bib,
            role_number=role_number,
            role=role,
            role_sub_type=role_sub_type,
            external_id=external_id,
            updated=updated,
            added=added,
        )

        return role_model
